<?php

// $Id: media_mover_ftp.inc,v 1.1.2.4 2008/12/11 05:16:18 arthuregg Exp $;

/**
 * Run the FTP harvest.
 *
 * @param array $file
 * @param int $action
 * @param array $configuration current configuration
 * @return array of files
 *
 * */
function media_mover_ftp_harvest(&$file_data_array, $action, $conf) {
  // build the ftp connection
  $ftp_conn = ftp_connect($conf['mm_ftp_host']);
  $ftp_login = ftp_login($ftp_conn, $conf['mm_ftp_user'], $conf['mm_ftp_pass']);
  $ftp_list = ftp_rawlist($ftp_conn, $conf['mm_ftp_dir']);

  // check the connection to the server
  if (! $ftp_conn) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Unable to connect to server %server', array('%server' => $conf['media_mover_ftp_host']), WATCHDOG_ERROR);
    return;
  }
  elseif (! $ftp_login) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Unable to login to server %server with username %user', array('%server' => $conf['media_mover_ftp_host'], '%user' => $conf['media_mover_ftp_user']), WATCHDOG_ERROR);
    return;
  }
  elseif ($ftp_list === FALSE) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Unable to get file list from server %server with username %user', array('%server' => $conf['media_mover_ftp_host'], '%user' => $conf['media_mover_ftp_user']), WATCHDOG_ERROR);
    return;
  }

  // make sure we have files being handed back
  $count = count($ftp_list);
  if ($count == 0) {
    return;
  }

  $del = $conf['mm_ftp_delete_files'];
  $file_types = explode(' ' , $conf['mm_ftp_allowed_files']);

  $date = date('Y-m-d H:i:s');
  $logfile = '';
  foreach($ftp_list as $item) {
    $info = array();
    $vinfo = preg_split("/[\s]+/", $item, 9);
    if ($vinfo[0][0] == "-") {
      $info['chmod'] = $vinfo[0];
      $info['name'] = $vinfo[8];
      $info['dir'] = $conf['mm_ftp_dir'];
      list($info['hour'], $info['minute']) = split(":", $vinfo[7]);
      $info['hour'] = $info['hour'] + 0; // mktime expects hour to be long, not a string
      $info['minute'] = $info['minute'] + 0; // mktime expects minute to be long, not a string
      $info['month'] = $vinfo[5] + 0; // mktime expects month to be long, not a string
      $info['day'] = $vinfo[6] + 0; // mktime expects day to be long, not a string
      $info['created'] = mktime($info['hour'], $info['minute'], 0, $info['month'], $info['day'], date(Y));
      $info['size'] = $vinfo[4];

      // get each file and add it on to the items
      if ($item = media_mover_ftp_harvest_ftp_file($ftp_conn, $info, $conf)) {
        $items[] = $item;
      }
    }
    else {
      // We're not looking at a file but at a directory ("d") or a link ("l") for instance
    }
  }
  ftp_close($ftp_conn);
  return $items;
}


/**
 * This goes through each of the files from the ftp server and harvests individual files
 * @param object $ftp_conn this is the connection to the ftp server
 * @param array $info this needs to be renamed to something more clear
 * @param array $configuration is the configuration currently running
 * @return array should be just a single item
 */
function media_mover_ftp_harvest_ftp_file(&$ftp_conn, $info, $configuration) {
  // Get each item and save it locally
  $item = media_mover_ftp_create_file($ftp_conn, $info, $configuration);

  // should we delete the file after we've harvested it?
  if ($configuration['mm_ftp_delete_files'] && ! ftp_delete($ftp_conn, $info['dir'] ."/". $info['name'])) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Error deleting file: @file', array('@file' => $info['name']), WATCHDOG_ERROR);
    return FALSE;
  }

  // return the item if we have it
  if ($item) {
    return $item;
  }
  return FALSE;
}


/**
 * function for saving the file from the FTP server to the local drupal directory
 * @param object $ftp_conn is the ftp connection
 * @param array $info is the info array
 * @param array $configuration is the media mover configuration
 * @return array $item is a item array
 */
function media_mover_ftp_create_file(&$ftp_conn, $info, $configuration) {
  // try to find a token on the file name
  $local_file = media_mover_ftp_token_extract($info['name'], 'file');

  // delete files without tokens when requested
  if ((! media_mover_ftp_token_extract($info['name'], 'file')) &&  $configuration['mm_ftp_delete_files_no_token']) {
    ftp_delete($ftp_conn, $info['dir'] ."/". $info['name']);
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Deleted FTP file without token.');
    return false;
  }

  // get file path from media mover
  $file_location = media_mover_api_dir_path() . MM_FTP_FILES_SUBDIRECTORY;

  // look out for dupes
  $local_file_path = file_create_filename($local_file, $file_location);

  // only harvested file types that match the requested types
  $errors = file_validate_extensions($local_file, $configuration['mm_ftp_allowed_files']);
  if (count($errors)) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'FTP file harvest failed: unsupported file extension !file', array('!file' => $local_file_path));
    return;
  }

  // download the file via FTP
  if (! ftp_get($ftp_conn, $local_file_path, $info['dir'] ."/". $info['name'], FTP_BINARY)) {
    watchdog(MM_FTP_WATCHDOG_TYPE, 'FTP file harvest failed to download file: !file', array('!file' => $local_file_path));
    return;
  }

  // @TODO we may want to lock this file down more, not sure. This is a potential
  //       security risk because we don't really know what the file is that has been
  //       downloaded. We can use the mimedetect library to help us determine what kind
  //       of file it is and remove it if we think it's dangerous.

  // types we support
  $types = array('video', 'image', 'audio', 'application/octet-stream');
  // get the mime value of the file we downloaded
  $mime = mimedetect_mime($local_file);
  foreach($types as $type) {
    if (stristr($mime, $type)) {
      // we think this is a safe file
      $legal = true;
    }
  }
  if (! $legal) {
    // log the error
    watchdog(MM_FTP_WATCHDOG_TYPE, 'Harvested an illegal MIME type: @mime for @file', array('@mime' => $mime, '@file' => $local_file_path));
    // delete the LOCAL file
    file_delete($local_file);
    return;
  }

  // log the harvested file
  watchdog(MM_FTP_WATCHDOG_TYPE, 'FTP file harvested: !file', array('!file' => $local_file_path));

  $item['filesize'] = $info['size'];
  $item['filename'] = $local_file;
  $item['filepath'] =  $local_file_path;
  $item['harvest_file'] = $local_file_path;
  $item['node']->title = $local_file;

  // get a user id from the token
  if ($user = media_mover_ftp_token_check(media_mover_ftp_token_extract($info['name'], 'token'))) {
    $item['user'] = $user;
    $item['node']->uid = $user->uid;
  }

  return $item;
}
